@@ -11,7 +11,7 @@ class Kraken_db:
         self.kf = KF(key_location, project_id)
         self.ks = KS(key_location)
 
-        self.base_path = 'v1/'
+        self.base_path = 'v1'
 
 
     def get(self, record_type, record_id):
